[PATCH 1/2] fdtable: Bound minimum allocation size.

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



This patch modifies the fdtable minimum allocation unit, setting it to a fixed
size of 1024 bytes instead of basing it on the architecture page size. This
leaves the algorithm heuristics unchanged for the common 4K page size, but
does rebalance the "memory wasted versus number of reallocations" tradeoff for
architectures with larger page sizes (like 64K).

Signed-off-by: Vadim Lobanov <[email protected]>

diff -Npru old/fs/file.c new/fs/file.c
--- old/fs/file.c	2006-10-11 19:55:51.000000000 -0700
+++ new/fs/file.c	2006-10-14 15:20:05.000000000 -0700
@@ -161,12 +161,12 @@ static struct fdtable * alloc_fdtable(un
 	 * Figure out how many fds we actually want to support in this fdtable.
 	 * Allocation steps are keyed to the size of the fdarray, since it
 	 * grows far faster than any of the other dynamic data. We try to fit
 	 * the fdarray into page-sized chunks: starting at a quarter of a page,
 	 * and growing in powers of two from there on.
 	 */
-	nr /= (PAGE_SIZE / 4 / sizeof(struct file *));
+	nr /= (1024 / sizeof(struct file *));
 	nr = roundup_pow_of_two(nr + 1);
-	nr *= (PAGE_SIZE / 4 / sizeof(struct file *));
+	nr *= (1024 / sizeof(struct file *));
 	if (nr > NR_OPEN)
 		nr = NR_OPEN;
 
-
@@ -161,12 +161,12 @@ static struct fdtable * alloc_fdtable(un
 	 * Allocation steps are keyed to the size of the fdarray, since it
 	 * grows far faster than any of the other dynamic data. We try to fit
-	 * the fdarray into page-sized chunks: starting at a quarter of a page,
+	 * the fdarray into comfortable page-tuned chunks: starting at 1024B
 	 * and growing in powers of two from there on.
 	 */
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

[Index of Archives]     [Kernel Newbies]     [Netfilter]     [Bugtraq]     [Photo]     [Stuff]     [Gimp]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Video 4 Linux]     [Linux for the blind]     [Linux Resources]
  Powered by Linux